<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_messages_memory_usage.case"></a>

# plugins.aea-cli-benchmark.aea`_`cli`_`benchmark.case`_`messages`_`memory`_`usage.case

Memory usage of huge amount of messages.

<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_messages_memory_usage.case.make_message"></a>

#### make`_`message

```python
def make_message() -> Message
```

Create a message.

<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_messages_memory_usage.case.run"></a>

#### run

```python
def run(messages_amount: int) -> List[Tuple[str, Union[int, float]]]
```

Test messages generation and memory consumption.

